# arpakitlib

## 🚀 Simplify Your Development Workflow

A collection of lightweight and convenient development tools by arpakit, designed to simplify and accelerate your
workflow

---

### Supported Python version

- Python 3.12.4+

---

### Installation methods

```
poetry add arpakitlib
# or
pip add arpakitlib
# or
poetry add git+https://github.com/ARPAKIT-Company/arpakitlib.git@master
```

---


## ❤️ Made by ARPAKIT Company ❤️


